import logging
import os
import serial

import config
import platforms
from base_detector import BaseDetector


class UARTPinsDetector(BaseDetector):

    PORT_PATH_BASE = "/dev/tty"

    def __init__(self, _=None):
        self.possible_port_paths = [ self.PORT_PATH_BASE + "S0" ]
        self.printerid_dict_template = {'VID': 'UART', 'PID': '', 'SNR': '0', 'COM': ''}
        self.first_run = True # this is a one shot detector, that will be updated only ones per run of application
        self.printers = []
        self.logger = logging.getLogger(self.__class__.__name__)

    def get_printers_list(self):
        # this is a one shot detector, that will be updated only ones per run of application
        if self.first_run and platforms.PLATFORM == "rpi":
            for port_path in self.possible_port_paths:
                try:
                    port = serial.Serial(port_path, 115200) # NOTE check the baudrate
                except:
                    pass
                else:
                    if port.isOpen():
                        port.close()
                        printerid_dict = {}
                        printerid_dict.update(self.printerid_dict_template)
                        printerid_dict["PID"] = port_path.replace(self.PORT_PATH_BASE, "")
                        printerid_dict["COM"] = port_path
                        if printerid_dict not in self.printers:
                            self.printers.append(printerid_dict)
            if self.printers:
                settings = config.get_settings()
                self.logger.info("Found UART Pin, disabling GPIO")
                settings['gpio']['enabled'] = False
            self.first_run = False
        return self.printers
